==> camel-k-crds-2.0.1-sources.jar: org/apache/camel/v1alpha1/kameletbindingstatus/conditions/Pods.java <==
package org.apache.camel.v1alpha1.kameletbindingstatus.conditions;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"condition","health","name"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class Pods implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * PodCondition contains details for the current condition of this pod.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("condition")
    @io.fabric8.generator.annotation.Required()
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("PodCondition contains details for the current condition of this pod.")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition condition;

    public org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition getCondition() {
        return condition;
    }

    public void setCondition(org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition condition) {
        this.condition = condition;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("health")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> health;

    public java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> getHealth() {
        return health;
    }

    public void setHealth(java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> health) {
        this.health = health;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("name")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String name;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}

==> camel-k-crds-2.3.0-sources.jar: org/apache/camel/v1alpha1/kameletbindingstatus/conditions/Pods.java <==
package org.apache.camel.v1alpha1.kameletbindingstatus.conditions;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"condition","health","name"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class Pods implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * PodCondition contains details for the current condition of this pod.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("condition")
    @io.fabric8.generator.annotation.Required()
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("PodCondition contains details for the current condition of this pod.")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition condition;

    public org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition getCondition() {
        return condition;
    }

    public void setCondition(org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Condition condition) {
        this.condition = condition;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("health")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> health;

    public java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> getHealth() {
        return health;
    }

    public void setHealth(java.util.List<org.apache.camel.v1alpha1.kameletbindingstatus.conditions.pods.Health> health) {
        this.health = health;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("name")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String name;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}
